# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .chunk_result import ChunkResult


class StructuredDataExtractorResponse(UniversalBaseModel):
    """
    The agent's response.
    """

    chunk_by_chunk_data: typing.Optional[typing.List[ChunkResult]] = pydantic.Field(default=None)
    """
    The extracted structured data for each chunk.  A list where each element is guaranteed to match `json_schema`.
    """

    reduced_data: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    If reduce is True, the reduced structured data, otherwise null.  Guaranteed to match `json_schema`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class DatabaseColumnInfo(UniversalBaseModel):
    """
    Column metadata for table schema response.
    """

    data_type: str = pydantic.Field()
    """
    PostgreSQL data type
    """

    default_value: typing.Optional[str] = pydantic.Field(default=None)
    """
    Default value expression
    """

    is_nullable: bool = pydantic.Field()
    """
    Whether the column allows NULL values
    """

    max_length: typing.Optional[int] = pydantic.Field(default=None)
    """
    Maximum length for character types
    """

    name: str = pydantic.Field()
    """
    Column name
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .content import Content


class ConversationMessage(UniversalBaseModel):
    """
    Model representing a single conversation message.
    """

    additional_kwargs: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Additional message metadata
    """

    content: Content = pydantic.Field()
    """
    Message content as text or structured content blocks
    """

    id: str = pydantic.Field()
    """
    Unique identifier for the message
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Tool name for tool messages
    """

    role: str = pydantic.Field()
    """
    Role of the message sender (user, assistant, system)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
